==> dokuwiki_0.0.20180422.a.orig.tar.gz: dokuwiki-2018-04-22a/lib/plugins/extension/lang/de/lang.php <==
<?php

/**
 * @license    GPL 2 (http://www.gnu.org/licenses/gpl.html)
 *
 * @author H. Richard <wanderer379@t-online.de>
 * @author Joerg <scooter22@gmx.de>
 * @author Simon <st103267@stud.uni-stuttgart.de>
 * @author Hoisl <hoisl@gmx.at>
 * @author Dominik Mahr <drache.mahr@gmx.de>
 * @author Noel Tilliot <noeltilliot@byom.de>
 * @author Philip Knack <p.knack@stollfuss.de>
 * @author Hella Breitkopf <hella.breitkopf@gmail.com>
 */
$lang['menu']                  = 'Erweiterungen verwalten';
$lang['tab_plugins']           = 'Installierte Plugins';
$lang['tab_templates']         = 'Installierte Templates';
$lang['tab_search']            = 'Suchen und Installieren';
$lang['tab_install']           = 'Manuell installieren';
$lang['notimplemented']        = 'Dieses Fähigkeit/Eigenschaft wurde noch nicht implementiert';
$lang['notinstalled']          = 'Diese Erweiterung ist nicht installiert';
$lang['alreadyenabled']        = 'Diese Erweiterung ist bereits aktiviert';
$lang['alreadydisabled']       = 'Diese Erweiterung ist bereits deaktiviert';
$lang['pluginlistsaveerror']   = 'Es gab einen Fehler beim Speichern der Plugin-Liste';
$lang['unknownauthor']         = 'Unbekannter Autor';
$lang['unknownversion']        = 'Unbekannte Version';
$lang['btn_info']              = 'Zeige weitere Info';
$lang['btn_update']            = 'Update';
$lang['btn_uninstall']         = 'Deinstallation';
$lang['btn_enable']            = 'Aktivieren';
$lang['btn_disable']           = 'Deaktivieren';
$lang['btn_install']           = 'Installieren';
$lang['btn_reinstall']         = 'Neu installieren';
$lang['js']['reallydel']       = 'Wollen Sie diese Erweiterung wirklich löschen?';
$lang['js']['display_viewoptions'] = 'Optionen anzeigen';
$lang['js']['display_enabled'] = 'aktiviert';
$lang['js']['display_disabled'] = 'deaktiviert';
$lang['js']['display_updatable'] = 'aktualisierbar';
$lang['search_for']            = 'Erweiterung suchen:';
$lang['search']                = 'Suchen';
$lang['extensionby']           = '<strong>%s</strong> von %s';
$lang['screenshot']            = 'Bildschirmfoto von %s';
$lang['popularity']            = 'Popularität: %s%%';
$lang['homepage_link']         = 'Doku';
$lang['bugs_features']         = 'Bugs';
$lang['tags']                  = 'Schlagworte';
$lang['author_hint']           = 'Suche weitere Erweiterungen dieses Autors';
$lang['installed']             = 'Installiert:';
$lang['downloadurl']           = 'URL zum Herunterladen:';
$lang['repository']            = 'Quelle:';
$lang['unknown']               = '<em>unbekannt</em>';
$lang['installed_version']     = 'Installierte Version:';
$lang['install_date']          = 'Ihr letztes Update:';
$lang['available_version']     = 'Verfügbare Version: ';
$lang['compatible']            = 'Kompatibel mit:';
$lang['depends']               = 'Benötigt:';
$lang['similar']               = 'Ist ähnlich zu:';
$lang['conflicts']             = 'Nicht kompatibel mit:';
$lang['donate']                = 'Nützlich?';
$lang['donate_action']         = 'Spendieren Sie dem Autor einen Kaffee!';
$lang['repo_retry']            = 'Neu versuchen';
$lang['provides']              = 'Enthält';
$lang['status']                = 'Status';
$lang['status_installed']      = 'installiert';
$lang['status_not_installed']  = 'nicht installiert';
$lang['status_protected']      = 'geschützt';
$lang['status_enabled']        = 'aktiviert';
$lang['status_disabled']       = 'deaktiviert';
$lang['status_unmodifiable']   = 'unveränderlich';
$lang['status_plugin']         = 'Plugin';
$lang['status_template']       = 'Template';
$lang['status_bundled']        = 'gebündelt';
$lang['msg_enabled']           = 'Plugin %s ist aktiviert';
$lang['msg_disabled']          = 'Erweiterung %s ist deaktiviert';
$lang['msg_delete_success']    = 'Erweiterung %s wurde entfernt';
$lang['msg_delete_failed']     = 'Deinstallation der Erweiterung %s fehlgeschlagen';
$lang['msg_template_install_success'] = 'Das Template %s wurde erfolgreich installiert';
$lang['msg_template_update_success'] = 'Das Update des Templates %s war erfolgreich ';
$lang['msg_plugin_install_success'] = 'Das Plugin %s wurde erfolgreich installiert';
$lang['msg_plugin_update_success'] = 'Das Update des Plugins %s war erfolgreich';
$lang['msg_upload_failed']     = 'Fehler beim Hochladen der Datei';
$lang['missing_dependency']    = '<strong>fehlende oder deaktivierte Abhängigkeit:<strong>%s';
$lang['security_issue']        = '<strong>Sicherheitsproblem:</strong> %s';
$lang['security_warning']      = '<strong>Sicherheitswarnung:</strong> %s';
$lang['update_available']      = '<strong>Update:</strong> Version %s steht zum Download bereit.';
$lang['wrong_folder']          = '<strong>Plugin wurde nicht korrekt installiert:</strong> Benennen Sie das Plugin-Verzeichnis "%s" in "%s" um.';
$lang['url_change']            = '<strong>URL geändert:</strong> Die Download URL wurde seit dem letzten Download geändert. Internetadresse vor Aktualisierung der Erweiterung auf Gültigkeit prüfen.<br />Neu: %s<br />Alt: %s';
$lang['error_badurl']          = 'URLs sollten mit http oder https beginnen';
$lang['error_dircreate']       = 'Temporärer Ordner konnte nicht erstellt werden, um Download zu abzuspeichern';
$lang['error_download']        = 'Download der Datei: %s nicht möglich.';
$lang['error_decompress']      = 'Die heruntergeladene Datei konnte nicht entpackt werden. Dies kann die Folge eines fehlerhaften Downloads sein. In diesem Fall sollten Sie versuchen den Vorgang zu wiederholen. Es kann auch die Folge eines unbekannten Kompressionsformates sein, in diesem ​​Fall müssen Sie die Datei selber herunterladen und manuell installieren.';
$lang['error_findfolder']      = 'Das Erweiterungs-Verzeichnis konnte nicht identifiziert werden, laden und installieren Sie die Datei manuell.';
$lang['error_copy']            = 'Beim Versuch Dateien in den Ordner <em>%s</em>: zu installieren trat ein Kopierfehler auf. Die Dateizugriffsberechtigungen könnten falsch sein. Dies kann an einem unvollständig installierten Plugin liegen und beeinträchtigt somit die Stabilität Ihre Wiki-Installation.';
$lang['noperms']               = 'Das Erweiterungs-Verzeichnis ist schreibgeschützt';
$lang['notplperms']            = 'Das Template-Verzeichnis ist schreibgeschützt';
$lang['nopluginperms']         = 'Das Plugin-Verzeichnis ist schreibgeschützt';
$lang['git']                   = 'Diese Erweiterung wurde über git installiert und sollte daher nicht hier aktualisiert werden.';
$lang['auth']                  = 'Dieses Auth Plugin ist in der Konfiguration nicht aktiviert, Sie sollten es deaktivieren.';
$lang['install_url']           = 'Von Webadresse (URL) installieren';
$lang['install_upload']        = 'Erweiterung hochladen:';
$lang['repo_error']            = 'Es konnte keine Verbindung zum Plugin-Verzeichnis hergestellt werden. Stellen sie sicher das der Server Verbindung mit www.dokuwiki.org aufnehmen darf und überprüfen sie ihre Proxy Einstellungen.';
$lang['nossl']                 = 'Ihr PHP scheint SSL nicht zu unterstützen. Das Herunterladen vieler DokuWiki Erweiterungen wird scheitern.';

==> dokuwiki_0.0.20220731.a.orig.tar.gz: dokuwiki-2022-07-31a/lib/plugins/extension/lang/de/lang.php <==
<?php

/**
 * @license    GPL 2 (http://www.gnu.org/licenses/gpl.html)
 *
 * @author Axel Schwarzer <SchwarzerA@gmail.com>
 * @author Benjamin Molitor <bmolitor@uos.de>
 * @author H. Richard <wanderer379@t-online.de>
 * @author Joerg <scooter22@gmx.de>
 * @author Simon <st103267@stud.uni-stuttgart.de>
 * @author Hoisl <hoisl@gmx.at>
 * @author Dominik Mahr <drache.mahr@gmx.de>
 * @author Noel Tilliot <noeltilliot@byom.de>
 * @author Philip Knack <p.knack@stollfuss.de>
 * @author Hella Breitkopf <hella.breitkopf@gmail.com>
 */
$lang['menu']                  = 'Erweiterungen verwalten';
$lang['tab_plugins']           = 'Installierte Plugins';
$lang['tab_templates']         = 'Installierte Templates';
$lang['tab_search']            = 'Suchen und Installieren';
$lang['tab_install']           = 'Manuell installieren';
$lang['notimplemented']        = 'Dieses Fähigkeit/Eigenschaft wurde noch nicht implementiert';
$lang['notinstalled']          = 'Diese Erweiterung ist nicht installiert';
$lang['alreadyenabled']        = 'Diese Erweiterung ist bereits aktiviert';
$lang['alreadydisabled']       = 'Diese Erweiterung ist bereits deaktiviert';
$lang['pluginlistsaveerror']   = 'Es gab einen Fehler beim Speichern der Plugin-Liste';
$lang['unknownauthor']         = 'Unbekannter Autor';
$lang['unknownversion']        = 'Unbekannte Version';
$lang['btn_info']              = 'Zeige weitere Info';
$lang['btn_update']            = 'Update';
$lang['btn_uninstall']         = 'Deinstallation';
$lang['btn_enable']            = 'Aktivieren';
$lang['btn_disable']           = 'Deaktivieren';
$lang['btn_install']           = 'Installieren';
$lang['btn_reinstall']         = 'Neu installieren';
$lang['js']['reallydel']       = 'Wollen Sie diese Erweiterung wirklich löschen?';
$lang['js']['display_viewoptions'] = 'Optionen anzeigen';
$lang['js']['display_enabled'] = 'aktiviert';
$lang['js']['display_disabled'] = 'deaktiviert';
$lang['js']['display_updatable'] = 'aktualisierbar';
$lang['search_for']            = 'Erweiterung suchen:';
$lang['search']                = 'Suchen';
$lang['extensionby']           = '<strong>%s</strong> von %s';
$lang['screenshot']            = 'Bildschirmfoto von %s';
$lang['popularity']            = 'Popularität: %s%%';
$lang['homepage_link']         = 'Doku';
$lang['bugs_features']         = 'Bugs';
$lang['tags']                  = 'Schlagworte';
$lang['author_hint']           = 'Suche weitere Erweiterungen dieses Autors';
$lang['installed']             = 'Installiert:';
$lang['downloadurl']           = 'Download-URL:';
$lang['repository']            = 'Quelle:';
$lang['unknown']               = '<em>unbekannt</em>';
$lang['installed_version']     = 'Installierte Version:';
$lang['install_date']          = 'Ihr letztes Update:';
$lang['available_version']     = 'Verfügbare Version: ';
$lang['compatible']            = 'Kompatibel mit:';
$lang['depends']               = 'Benötigt:';
$lang['similar']               = 'Ist ähnlich zu:';
$lang['conflicts']             = 'Nicht kompatibel mit:';
$lang['donate']                = 'Nützlich?';
$lang['donate_action']         = 'Spendieren Sie dem Autor einen Kaffee!';
$lang['repo_retry']            = 'Neu versuchen';
$lang['provides']              = 'Enthält';
$lang['status']                = 'Status';
$lang['status_installed']      = 'installiert';
$lang['status_not_installed']  = 'nicht installiert';
$lang['status_protected']      = 'geschützt';
$lang['status_enabled']        = 'aktiviert';
$lang['status_disabled']       = 'deaktiviert';
$lang['status_unmodifiable']   = 'unveränderlich';
$lang['status_plugin']         = 'Plugin';
$lang['status_template']       = 'Template';
$lang['status_bundled']        = 'gebündelt';
$lang['msg_enabled']           = 'Plugin %s ist aktiviert';
$lang['msg_disabled']          = 'Erweiterung %s ist deaktiviert';
$lang['msg_delete_success']    = 'Erweiterung %s wurde entfernt';
$lang['msg_delete_failed']     = 'Deinstallation der Erweiterung %s fehlgeschlagen';
$lang['msg_template_install_success'] = 'Das Template %s wurde erfolgreich installiert';
$lang['msg_template_update_success'] = 'Das Update des Templates %s war erfolgreich ';
$lang['msg_plugin_install_success'] = 'Das Plugin %s wurde erfolgreich installiert';
$lang['msg_plugin_update_success'] = 'Das Update des Plugins %s war erfolgreich';
$lang['msg_upload_failed']     = 'Fehler beim Hochladen der Datei';
$lang['msg_nooverwrite']       = 'Die Erweiterung %s ist bereits vorhanden, sodass sie nicht überschrieben wird. Zum Überschreiben aktivieren Sie die Option "Überschreiben".';
$lang['missing_dependency']    = '<strong>fehlende oder deaktivierte Abhängigkeit:<strong>%s';
$lang['security_issue']        = '<strong>Sicherheitsproblem:</strong> %s';
$lang['security_warning']      = '<strong>Sicherheitswarnung:</strong> %s';
$lang['update_available']      = '<strong>Update:</strong> Version %s steht zum Download bereit.';
$lang['wrong_folder']          = '<strong>Plugin wurde nicht korrekt installiert:</strong> Benennen Sie das Plugin-Verzeichnis "%s" in "%s" um.';
$lang['url_change']            = '<strong>URL geändert:</strong> Die Download-URL wurde seit dem letzten Download geändert. Internetadresse vor Aktualisierung der Erweiterung auf Gültigkeit prüfen.<br />Neu: %s<br />Alt: %s';
$lang['error_badurl']          = 'URLs sollten mit http oder https beginnen';
$lang['error_dircreate']       = 'Temporärer Ordner konnte nicht erstellt werden, um Download zu abzuspeichern';
$lang['error_download']        = 'Download der Datei: %s nicht möglich.';
$lang['error_decompress']      = 'Die heruntergeladene Datei konnte nicht entpackt werden. Dies kann die Folge eines fehlerhaften Downloads sein. In diesem Fall sollten Sie versuchen den Vorgang zu wiederholen. Es kann auch die Folge eines unbekannten Kompressionsformates sein, in diesem Fall müssen Sie die Datei selber herunterladen und manuell installieren.';
$lang['error_findfolder']      = 'Das Erweiterungs-Verzeichnis konnte nicht identifiziert werden, laden und installieren Sie die Datei manuell.';
$lang['error_copy']            = 'Beim Versuch Dateien in den Ordner <em>%s</em>: zu installieren trat ein Kopierfehler auf. Die Dateizugriffsberechtigungen könnten falsch sein. Dies kann an einem unvollständig installierten Plugin liegen und beeinträchtigt somit die Stabilität Ihre Wiki-Installation.';
$lang['noperms']               = 'Das Erweiterungs-Verzeichnis ist schreibgeschützt';
$lang['notplperms']            = 'Das Template-Verzeichnis ist schreibgeschützt';
$lang['nopluginperms']         = 'Das Plugin-Verzeichnis ist schreibgeschützt';
$lang['git']                   = 'Diese Erweiterung wurde über git installiert und sollte daher nicht hier aktualisiert werden.';
$lang['auth']                  = 'Dieses Auth-Plugin ist in der Konfiguration nicht aktiviert, Sie sollten es deaktivieren.';
$lang['install_url']           = 'Von Webadresse (URL) installieren';
$lang['install_upload']        = 'Erweiterung hochladen:';
$lang['repo_error']            = 'Es konnte keine Verbindung zum Plugin-Verzeichnis hergestellt werden. Stellen Sie sicher, dass der Server Verbindung mit www.dokuwiki.org aufnehmen darf und überprüfen Sie ihre Proxy-Einstellungen.';
$lang['nossl']                 = 'Ihr PHP scheint SSL nicht zu unterstützen. Das Herunterladen vieler DokuWiki-Erweiterungen wird scheitern.';
